@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2019 Slawomir Wojtasiak
+ * Copyright (C) 2010-2024 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -39,20 +39,13 @@ extern "C" {
 
 /** Optimizer context used as a connector with the environment. */
 typedef struct fcml_st_asm_optimizer_context {
+    /** Instruction's entry point provided by the caller. The
+     * same which is available in the assembler context. */
+    const fcml_st_entry_point *entry_point;
     /** Optimizer flags passed through the assembler context.
      * @see fcml_st_assembler_conf
      */
     fcml_uint16_t optimizer_flags;
-    /** Processor operating mode 16/32/64-bit. */
-    fcml_en_operating_mode op_mode;
-    /** Default address size attribute not modified by prefixes yet.
-     * (See 'D' flag of segment descriptor.)
-     */
-    fcml_usize asa;
-    /** Default operand size attribute not modified by prefixes yet.
-     * (See 'D' flag of segment descriptor.)
-     */
-    fcml_usize osa;
 } fcml_st_asm_optimizer_context;
 
 /** Processing details for optimizers. */
@@ -64,7 +57,7 @@ typedef struct fcml_st_asm_optimizer_processing_details {
     fcml_st_nullable_size_flags allowed_eosa;
     /** Allowed values of the address size attribute calculated by the
      * assembler engine.
-     * It is optimizer who decides which one should be finally used.
+     * It is the optimizer who decides which one should be finally used.
      */
     fcml_st_nullable_size_flags allowed_easa;
     /** Effective address size attribute chosen for currently processed
@@ -78,7 +71,7 @@ typedef struct fcml_st_asm_optimizer_processing_details {
     /** Effective operand size attribute chosen for currently processed
      * instruction form.
      * If it is set it can not be changed anymore. It has higher priority than
-     * flags above. Take into account that it is effective operand size
+     * flags above. Take into account that it is the effective operand size
      * attribute so it can be forced using instruction prefixes to override
      * the default attribute size.
      */
