@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2020 Slawomir Wojtasiak
+ * Copyright (C) 2010-2024 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -56,25 +56,26 @@
 /* Operand size calculated by Effective
  * Operand Size Attribute and Effective Address Size Attribute.
  */
-#define FCML_EOS_EOSA           0x7F
-#define FCML_EOS_EASA           0x7E
+#define FCML_EOS_EOSA           (FCML_EOS_DYNAMIC_BASE + 0x0F)
+#define FCML_EOS_EASA           (FCML_EOS_DYNAMIC_BASE + 0x0E)
 
 /* Operand size calculated on EVEX.L'L/VEX.L/XOP/L fields. */
-#define FCML_EOS_L              0x7D
+#define FCML_EOS_L              (FCML_EOS_DYNAMIC_BASE + 0x0D)
 
 /* Operand sizes that cannot be simply written as number of bytes.*/
-#define FCML_EOS_14_28          0x7C
-#define FCML_EOS_94_108         0x7B
-#define FCML_EOS_32_64          0x7A
+#define FCML_EOS_14_28          (FCML_EOS_DYNAMIC_BASE + 0x0C)
+#define FCML_EOS_94_108         (FCML_EOS_DYNAMIC_BASE + 0x0B)
+#define FCML_EOS_32_64          (FCML_EOS_DYNAMIC_BASE + 0x0A)
 
 /* Far pointer indirect.*/
-#define FCML_EOS_FPI            0x79
+#define FCML_EOS_FPI            (FCML_EOS_DYNAMIC_BASE + 0x09)
 
 /* Far pointer.*/
-#define FCML_EOS_FP             0x78
+#define FCML_EOS_FP             (FCML_EOS_DYNAMIC_BASE + 0x08)
 
 /* True if encoded operand size is a dynamic one.*/
-#define FCML_IS_EOS_DYNAMIC(x)  (((x) & 0x40) != 0)
+#define FCML_IS_EOS_DYNAMIC(x)  (((x) & FCML_EOS_DYNAMIC_BASE) == \
+        FCML_EOS_DYNAMIC_BASE)
 #define FCML_IS_EOS_OPT(x)      (((x) & 0x80) != 0)
 #define FCML_GET_OS(x)          ((x) & ~FCML_EOS_OPT)
 
@@ -131,7 +132,6 @@ typedef fcml_uint32_t fcml_operand_decorators;
 /* Predicate operand is mandatory and cannot be omited. */
 #define FCML_DECOR_K1_REQ     (0x400000000000LL | FCML_DECOR_K1)
 
-
 /* Operand decorators decoders. Use only on 'fcml_operand_decorators'. */
 
 #define FCML_IS_DECOR_BCAST(x)                ((x) & 0x00000001)
@@ -253,13 +253,13 @@ typedef struct fcml_st_def_instruction_desc {
  * asserted or negated. The field is located in opcode byte. */
 #define FCML_DEF_OPCODE_FLAGS_OPCODE_FIELD_TTTN(x)          ((x) & 0x00000040)
 #define FCML_DEF_OPCODE_FLAGS_64BITS_EOSA_BY_DEFAULT(x)     ((x) & 0x00000080)
-#define FCML_DEF_OPCODE_FLAGS_POS(x)                  (((x) & 0x00000700) >> 8)
-#define FCML_DEF_OPCODE_FLAGS_OPCODE_EXT(x)           (((x) & 0x00007800) >> 11)
-#define FCML_DEF_OPCODE_FLAGS_OPCODE_IS_MODRM(x)      FCML_TP_GET_BIT(x,15)
+#define FCML_DEF_OPCODE_FLAGS_POS(x)                        (((x) & 0x00000700) >> 8)
+#define FCML_DEF_OPCODE_FLAGS_OPCODE_EXT(x)                 (((x) & 0x00007800) >> 11)
+#define FCML_DEF_OPCODE_FLAGS_OPCODE_IS_MODRM(x)            FCML_TP_GET_BIT(x,15)
 /* Reg/Opcode field is used as an opcode extension. */
-#define FCML_DEF_OPCODE_FLAGS_OPCODE_IS_EXT(x)        FCML_TP_GET_BIT(x,16)
-#define FCML_DEF_OPCODE_FLAGS_OPCODE_NUM(x)           (((x) & 0x000C0000) >> 18)
-#define FCML_DEF_OPCODE_FLAGS_PRIMARY_OPCODE(x)       (((x) & 0x00300000) >> 20)
+#define FCML_DEF_OPCODE_FLAGS_OPCODE_IS_EXT(x)              FCML_TP_GET_BIT(x,16)
+#define FCML_DEF_OPCODE_FLAGS_OPCODE_NUM(x)                 (((x) & 0x000C0000) >> 18)
+#define FCML_DEF_OPCODE_FLAGS_PRIMARY_OPCODE(x)             (((x) & 0x00300000) >> 20)
 #define FCML_DEF_OPCODE_FLAGS_64_BIT_MODE_SUPPORTED(x)      ((x) & 0x00800000)
 #define FCML_DEF_OPCODE_FLAGS_16_32_BIT_MODE_SUPPORTED(x)   ((x) & 0x00400000)
 #define FCML_DEF_OPCODE_FLAGS_EOSA_16(x)                    ((x) & 0x01000000)
