@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2015 Slawomir Wojtasiak
+ * Copyright (C) 2010-2020 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,9 +20,8 @@
 #include <fcml_dialect.h>
 #include "fcml_dialect_int.h"
 
-void LIB_CALL fcml_fn_dialect_free( fcml_st_dialect *dialect ) {
-    if ( dialect ) {
-        fcml_st_dialect_context_int *context = (fcml_st_dialect_context_int*) dialect;
-        context->free_dialect( dialect );
+void LIB_CALL fcml_fn_dialect_free(fcml_st_dialect *dialect) {
+    if (dialect) {
+        ((fcml_st_dialect_context_int*) dialect)->free_dialect(dialect);
     }
 }
