@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2015 Slawomir Wojtasiak
+ * Copyright (C) 2010-2020 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -34,27 +34,31 @@
 void gas_error(YYLTYPE *yylloc, struct fcml_st_parser_data *pd,
         const char *error) {
     /* Stores parser error into standard container.*/
-    fcml_fn_ceh_add_error( &( pd->errors ), (const fcml_string) error, FCML_CEH_MEC_ERROR_INVALID_SYNTAX, FCML_EN_CEH_EL_ERROR );
+    fcml_fn_ceh_add_error(&(pd->errors), (const fcml_string) error,
+            FCML_CEH_MEC_ERROR_INVALID_SYNTAX, FCML_EN_CEH_EL_ERROR);
 }
 
-void *gas_alloc( yy_size_t size, yyscan_t yyscanner ) {
-    return fcml_fn_env_memory_alloc( (fcml_usize) size );
+void* gas_alloc(yy_size_t size, yyscan_t yyscanner) {
+    return fcml_fn_env_memory_alloc((fcml_usize) size);
 }
 
-void *gas_realloc( void *ptr, yy_size_t size, yyscan_t yyscanner ) {
-    return fcml_fn_env_memory_realloc( ptr, (fcml_usize) size );
+void* gas_realloc(void *ptr, yy_size_t size, yyscan_t yyscanner) {
+    return fcml_fn_env_memory_realloc(ptr, (fcml_usize) size);
 }
 
-void gas_free( void *ptr, yyscan_t yyscanner ) {
-    return fcml_fn_env_memory_free( ptr );
+void gas_free(void *ptr, yyscan_t yyscanner) {
+    return fcml_fn_env_memory_free(ptr);
 }
 
-fcml_ceh_error fcml_fn_gas_parse_instruction_to_ast( fcml_ip ip, const fcml_string mnemonic, fcml_st_parser_ast *ast ) {
+fcml_ceh_error fcml_fn_gas_parse_instruction_to_ast(fcml_ip ip,
+        const fcml_string mnemonic, fcml_st_parser_ast *ast) {
 
     fcml_ceh_error error = FCML_CEH_GEC_NO_ERROR;
 
     /* Instruction size is limited to prevent from parser's stack and buffer overflows. */
-    if ( !mnemonic || !ast || fcml_fn_env_str_strlen( mnemonic ) > FCML_PARSER_MAX_INSTRUCTION_LEN ) {
+    if (!mnemonic || !ast
+            || fcml_fn_env_str_strlen(mnemonic)
+                    > FCML_PARSER_MAX_INSTRUCTION_LEN) {
         return FCML_CEH_GEC_INVALID_INPUT;
     }
 
@@ -63,22 +67,22 @@ fcml_ceh_error fcml_fn_gas_parse_instruction_to_ast( fcml_ip ip, const fcml_stri
     parser.ip = ip;
 
     /* Set up scanner. */
-    if ( gas_lex_init_extra( &parser, &( parser.scannerInfo ) ) ) {
+    if (gas_lex_init_extra(&parser, &(parser.scannerInfo))) {
         return FCML_CEH_GEC_OUT_OF_MEMORY;
     }
 
-    gas__scan_string( mnemonic, parser.scannerInfo );
+    gas__scan_string(mnemonic, parser.scannerInfo);
 
-    int yyresult = gas_parse( &parser );
+    int yyresult = gas_parse(&parser);
 
-    gas_lex_destroy( parser.scannerInfo );
+    gas_lex_destroy(parser.scannerInfo);
 
     ast->errors = parser.errors;
     ast->symbol = parser.symbol;
     ast->tree = parser.tree;
 
-    if ( yyresult ) {
-        switch ( yyresult ) {
+    if (yyresult) {
+        switch (yyresult) {
         case 1: /*Syntax error.*/
             error = FCML_CEH_GEC_INVALID_INPUT;
             break;
@@ -89,6 +93,4 @@ fcml_ceh_error fcml_fn_gas_parse_instruction_to_ast( fcml_ip ip, const fcml_stri
     }
 
     return error;
-
 }
-
