@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2015 Slawomir Wojtasiak
+ * Copyright (C) 2010-2020 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +26,7 @@
 
 #include "fcml_parser_int.h"
 
-fcml_ceh_error fcml_fn_gas_parse_instruction_to_ast( fcml_ip ip, const fcml_string mnemonic, fcml_st_parser_ast *ast );
+fcml_ceh_error fcml_fn_gas_parse_instruction_to_ast(fcml_ip ip,
+        const fcml_string mnemonic, fcml_st_parser_ast *ast);
 
 #endif /* FCML_GAS_PARSER_H_ */
