@@ -1,6 +1,6 @@
 /*
  * FCML - Free Code Manipulation Library.
- * Copyright (C) 2010-2017 Slawomir Wojtasiak
+ * Copyright (C) 2010-2020 Slawomir Wojtasiak
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -29,13 +29,13 @@
 
 /* Some macros that might be also useful outside decoder.*/
 
-#define FCML_MODRM_DEC_MOD(x)			( x >> 6 )
-#define FCML_MODRM_DEC_REG_OPCODE(x)	( ( x & 0x38 ) >> 3 )
-#define FCML_MODRM_DEC_RM(x)			( x & 0x07 )
+#define FCML_MODRM_DEC_MOD(x)			(x >> 6)
+#define FCML_MODRM_DEC_REG_OPCODE(x)	((x & 0x38) >> 3)
+#define FCML_MODRM_DEC_RM(x)			(x & 0x07)
 
-#define FCML_MODRM_SIB_SS(x)			( x >> 6 )
-#define FCML_MODRM_SIB_INDEX(x)			( ( x & 0x38 ) >> 3 )
-#define FCML_MODRM_SIB_BASE(x)			( x & 0x07 )
+#define FCML_MODRM_SIB_SS(x)			(x >> 6)
+#define FCML_MODRM_SIB_INDEX(x)			((x & 0x38) >> 3)
+#define FCML_MODRM_SIB_BASE(x)			(x& 0x07)
 
 #define FCML_MODRM_DEC_FLAG_EXTEND_DISPLACEMENT_TO_ASA		0x01
 
@@ -93,17 +93,12 @@ typedef struct fcml_st_modrm_decoder_context {
     fcml_bool b;
 } fcml_st_modrm_decoder_context;
 
-fcml_ceh_error fcml_fn_modrm_decode(
-        fcml_st_modrm_decoder_context *context,
-        fcml_st_modrm_source *modrm_source,
-        fcml_st_modrm *decoded_modrm,
-        fcml_st_modrm_details *modrm_details,
-        fcml_uint8_t flags );
+fcml_ceh_error fcml_fn_modrm_decode(fcml_st_modrm_decoder_context *context,
+        fcml_st_modrm_source *modrm_source, fcml_st_modrm *decoded_modrm,
+        fcml_st_modrm_details *modrm_details, fcml_uint8_t flags);
 
-fcml_ceh_error fcml_fn_modrm_decode_rip(
-        fcml_uint64_t rip,
-        fcml_usize effective_address_size,
-        fcml_st_offset *offset,
-        fcml_st_offset *address );
+fcml_ceh_error fcml_fn_modrm_decode_rip(fcml_uint64_t rip,
+        fcml_usize effective_address_size, fcml_st_offset *offset,
+        fcml_st_offset *address);
 
 #endif /* FCML_MODRM_DECODER_H_ */
